@@ -69,27 +69,6 @@ DEBUG = True
 DEBUG_PROPAGATE_EXCEPTIONS = True
 TEMPLATE_DEBUG = DEBUG
 
-# Application URL prefix defines where the application is located at
-# runtime with regards to URLs. Data URL prefix does the same but for
-# static and media files.
-#
-# Development settings use empty value to make localhost:8000 point
-# to the application. Production values can use anything but this
-# needs to be in sync with web server configuration. Debian
-# recommends package name as the prefix so that multiple web
-# applications can co-exists on one server without
-# namespace clashes.
-#
-# The prefix _MUST_ end with a slash when not empty.
-
-# Code is served directly, WSGI mapping make it appear in "lava-server" but
-# this is done externally to django URL resolver.
-APP_URL_PREFIX = r""
-# Data is served by external web server in "lava-server/"
-DATA_URL_PREFIX = r""
-
-
-# XXX: this is ugly!
 # It would be good to have rails-like configuration file in the future
 devel_db = os.getenv("DEVEL_DB", "sqlite")
 if devel_db == "pgsql":
@@ -125,45 +104,31 @@ MEDIA_ROOT = os.path.join(PROJECT_STATE_DIR, "media", devel_db)
 # Example: "/home/media/static.lawrence.com/"
 STATIC_ROOT = os.path.join(PROJECT_STATE_DIR, "static")
 
-# URL that handles the media served from MEDIA_ROOT. Make sure to use a
-# trailing slash if there is a path component (optional in other cases).
-# Examples: "http://media.lawrence.com", "http://example.com/media/"
-MEDIA_URL = "/" + DATA_URL_PREFIX + "media/"
-
-# URL that handles the media served from STATIC_ROOT. Make sure to use a
-# trailing slash if there is a path component (optional in other cases).
-# Examples: "http://static.lawrence.com", "http://example.com/static/"
-STATIC_URL = "/" + DATA_URL_PREFIX + "static/"
-
-# URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
-# trailing slash.
-# Examples: "http://foo.com/media/", "/media/".
-ADMIN_MEDIA_PREFIX = "/" + DATA_URL_PREFIX + "static/admin/"
-
-if not DEBUG:
-    raise Exception(
-        "You need to configure MEDIA_URL, STATIC_URL and ADMIN_MEDIA_PREFIX to"
-        "point to a production web server")
 
 # Make this unique, and don't share it with anybody.
 SECRET_KEY = '00000000000000000000000000000000000000000000000000'
 
-
+# Use templates from the checkout directory
 TEMPLATE_DIRS = (
     os.path.join(PROJECT_SRC_DIR, "templates"),
 )
 
-STATICFILES_DIRS = [('lava-server', os.path.join(PROJECT_SRC_DIR, 'htdocs'))]
+# Serve static files used by lava-server from the checkout directory
+STATICFILES_DIRS = [
+    ('lava-server', os.path.join(PROJECT_SRC_DIR, 'htdocs'))]
 
 
+# Try using devserver if available, devserver is a very useful extension that
+# makes debugging applications easier. It shows a lot of interesting output,
+# like SQL queries and timings for each request. It also supports
+# multi-threaded or multi-process server so some degree of parallelism can be
+# achieved.
 try:
     import devserver
     INSTALLED_APPS += ['devserver']
 except ImportError:
     pass
 
-# Login redirects back to home
-LOGIN_REDIRECT_URL = '/'
 
 # Any emails that would normally be sent are redirected to stdout.
 # This setting is only used for django 1.2 and newer.
